===============
Light Character
===============


.. image:: https://img.shields.io/pypi/v/light-character.svg
        :target: https://pypi.python.org/pypi/light-character

.. image:: https://github.com/paul-butcher/light_character/workflows/Python%20Tests/badge.svg
        :alt: Test status

.. image:: https://readthedocs.org/projects/light-character/badge/?version=latest
        :target: https://light-character.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: docs/_static/header.gif

Light Character illustrates light characteristics as found on charts and light lists.
It is not intended as a navigational aid, it simply gives an idea as to how
a given light characteristic might appear.



* Free software: MIT license
* Documentation: https://light-character.readthedocs.io.



Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

Images of lighthouses are from the `Royal Museums Greenwich`_ collection,
via Europeana_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`Royal Museums Greenwich`: https://www.rmg.co.uk/
.. _Europeana: https://www.europeana.eu/
